# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TermTagsUpdateParams(UniversalBaseModel):
    """
    Parameters for updating the tags of an existing glossary term.
    """

    add: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of tag IDs to add to the term
    """

    remove: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of tag IDs to remove from the term
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
