# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import datetime as dt
import typing
from .utterance_field import UtteranceField
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Utterance(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Unique identifier for the tag
    """

    creation_utc: dt.datetime = pydantic.Field()
    """
    UTC timestamp of when the utterance was created
    """

    value: str = pydantic.Field()
    """
    The textual content of the utterance.
    """

    fields: typing.List[UtteranceField] = pydantic.Field()
    """
    A sequence of utterance fields associated with the utterance.
    """

    tags: typing.List[str] = pydantic.Field()
    """
    Collection of tag IDs associated with the utterance.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
