# This file was auto-generated by Fern from our API Definition.

import typing

CompositionModeDto = typing.Union[
    typing.Literal[
        "fluid", "strict_utterance", "composited_utterance", "fluid_utterance"
    ],
    typing.Any,
]
