# This file was auto-generated by Fern from our API Definition.

import typing

RelationshipKindDto = typing.Union[
    typing.Literal["entailment", "priority", "dependency", "overlap"], typing.Any
]
