# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .payload_kind_dto import PayloadKindDto
import typing
from .guideline_payload import GuidelinePayload
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Payload(UniversalBaseModel):
    """
    A container for a guideline payload along with its kind

    Only `"guideline"` is available at this point.
    """

    kind: PayloadKindDto = "guideline"
    guideline: typing.Optional[GuidelinePayload] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
