# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
from .event import Event
import typing
from .event_trace import EventTrace
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class EventInspectionResult(UniversalBaseModel):
    """
    Result of inspecting an event.
    """

    session_id: str = pydantic.Field()
    """
    Unique identifier for the session
    """

    event: Event
    trace: typing.Optional[EventTrace] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
